TapeSlider class

Inheritance

Constructors

TapeSlider({Key? key, double initialValue = 50.0, double minValue = 0.0, double maxValue = 100.0, required dynamic onValueChanged(double), Axis orientation = Axis.horizontal, double itemExtent = 15.0, Color activeColor = Colors.blue, Color inactiveColor = Colors.grey, double trackHeight = 100.0, double trackWidth = double.infinity, TextStyle majorTickLabelStyle = const TextStyle(fontSize: 14, fontWeight: FontWeight.bold, color: Colors.white), TextStyle minorTickLabelStyle = const TextStyle(fontSize: 12, color: Colors.white70), bool showLabels = true, double indicatorThickness = 2.0, Color indicatorColor = Colors.white, int tickInterval = 1, int labelInterval = 5, double slidingAreaExtent = 250.0})
const

Properties

activeColor Color
final
hashCode int
The hash code for this object.
no setterinherited
inactiveColor Color
final
indicatorColor Color
final
indicatorThickness double
final
initialValue double
final
itemExtent double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelInterval int
final
majorTickLabelStyle TextStyle
final
maxValue double
final
minorTickLabelStyle TextStyle
final
minValue double
final
onValueChanged → dynamic Function(double)
final
orientation Axis
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabels bool
final
slidingAreaExtent double
final
tickInterval int
final
trackHeight double
final
trackWidth double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TapeSlider>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited